@@ -27,8 +27,6 @@
 
 #include <gtk/gtk.h>
 #include <glib/gprintf.h>
-#include <gnet.h>
-#include <glade/glade.h>
 #include <string.h>
 
 #include "glib/gi18n.h"
@@ -262,25 +260,20 @@ static gboolean
 gyrus_admin_mailbox_exists (GyrusAdmin *admin,
 			    const gchar *mailbox)
 {
-	GIOError error = G_IO_ERROR_NONE;
 	GyrusImapStatus status;
 	
 	gchar *msg = g_strdup_printf (". list \"\" \"%s\"\n", mailbox);
-	error = gyrus_admin_write_channel (admin, msg);
+	gyrus_admin_write_channel (admin, msg);
 	g_free (msg);
 
 	status = gyrus_admin_listen_channel (admin, &msg, NULL);
+	g_free (msg);
 	if (status == GYRUS_IMAP_STATUS_LIST) {
-		/* we have a coincidence. free the incoming buffer */
-		g_free (msg);
-
 		gyrus_admin_listen_channel (admin, &msg, NULL);
 		g_free (msg);
 
 		return TRUE;
 	}
-	
-	g_free (msg);
 
 	return FALSE;
 }
@@ -323,7 +316,6 @@ gboolean
 gyrus_admin_mailbox_new (GyrusAdmin *admin, const gchar *mailbox,
 			 const gchar *path, gint quota, gchar **error)
 {
-	GIOError ioerror = G_IO_ERROR_NONE;
 	GyrusImapStatus status;
 	gchar *new_mailbox;
 	gchar *msg;
@@ -354,7 +346,7 @@ gyrus_admin_mailbox_new (GyrusAdmin *admin, const gchar *mailbox,
 	}
 
 	msg = g_strdup_printf (". create \"%s\"\n", new_mailbox);
-	ioerror = gyrus_admin_write_channel (admin, msg);
+	gyrus_admin_write_channel (admin, msg);
 	g_free (msg);
 
 	status = gyrus_admin_listen_channel (admin, &msg, NULL);
@@ -362,6 +354,7 @@ gyrus_admin_mailbox_new (GyrusAdmin *admin, const gchar *mailbox,
 		g_free (msg);
 		*error = g_strdup (_("Unable to create the mailbox. "
 				     "Are you sure do you have the appropriate permissions?"));
+		g_free (new_mailbox);
 		return FALSE;
 	}
 
@@ -372,9 +365,12 @@ gyrus_admin_mailbox_new (GyrusAdmin *admin, const gchar *mailbox,
 						    quota)) {
 			*error = g_strdup (_("Mailbox created, "
 					     "but could not set quota."));
+			g_free (new_mailbox);
 			return FALSE;
 		}
 	}
+
+	g_free (new_mailbox);
 	return TRUE;
 }
 
