@@ -24,7 +24,7 @@
 #include <config.h>
 
 #include <gtk/gtk.h>
-#include <glade/glade.h>
+#include <gio/gio.h>
 #include <string.h>
 #include <glib/gi18n.h>
 
@@ -54,7 +54,6 @@ enum {
 static gint admin_signals [SIGNAL_LAST];
 
 static void gyrus_admin_finalize (GObject *object);
-static void gyrus_admin_destroy (GtkObject *object);
 
 static void gyrus_admin_initialize_mailbox_tree_view (GyrusAdmin *admin, 
 						      gboolean is_orphaned);
@@ -100,7 +99,6 @@ static void
 gyrus_admin_class_init (GyrusAdminClass *class)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (class);
-	GtkObjectClass *object_class = GTK_OBJECT_CLASS (class);
 
 	GType selection_changed_types [1] = {
 		G_TYPE_BOOLEAN
@@ -109,7 +107,6 @@ gyrus_admin_class_init (GyrusAdminClass *class)
 	gyrus_admin_parent_class = g_type_class_peek_parent (class);
 
 	gobject_class->finalize = gyrus_admin_finalize;
-	object_class->destroy = gyrus_admin_destroy;
 	
 	admin_signals [CONNECTED] = 
 		g_signal_newv ("connected", 
@@ -166,59 +163,46 @@ static void
 gyrus_admin_init_get_widgets (GyrusAdmin *admin)
 {
 	GyrusAdminPrivate *priv = admin->priv;
-	GladeXML *xml_page;
-	gchar *file_glade;
+	gchar *file_xml;
 	GtkWidget *table;
+	GtkBuilder *builder;
 
-	file_glade = g_build_filename (GYRUS_GLADE_DIR, "page.glade", NULL);
-	xml_page = glade_xml_new (file_glade, "table_page", "gyrus");
+	file_xml = g_build_filename (GYRUS_UI_DIR, "page.xml", NULL);
+
+        builder = gtk_builder_new ();
+        gtk_builder_add_from_file (builder, file_xml, NULL);
 	
-	g_free (file_glade);
+	g_free (file_xml);
 	
-	priv->treeview_users =
-		GTK_TREE_VIEW (glade_xml_get_widget (xml_page,
-						     "treeview_users"));
-	priv->treeview_corrupt_mailbox = 
-		GTK_TREE_VIEW (glade_xml_get_widget (xml_page, 
-						     "treeview_corrupt_mailbox"));
-	priv->treeview_acl =
-		GTK_TREE_VIEW (glade_xml_get_widget (xml_page,
-						     "treeview_acl"));
-	priv->label_acl    = glade_xml_get_widget (xml_page, "label_acl");
-	priv->scrolled_acl = glade_xml_get_widget (xml_page, "scrolled_acl");
+	priv->treeview_users = GTK_TREE_VIEW (gtk_builder_get_object (builder,"treeview_users"));
+	priv->treeview_corrupt_mailbox = GTK_TREE_VIEW (gtk_builder_get_object (builder,"treeview_corrupt_mailbox"));
+	priv->treeview_acl = GTK_TREE_VIEW (gtk_builder_get_object (builder,"treeview_acl"));
+	priv->label_acl = GTK_WIDGET (gtk_builder_get_object (builder, "label_acl"));
+	priv->scrolled_acl = GTK_WIDGET (gtk_builder_get_object (builder, "scrolled_acl"));
+
+	priv->label_host = GTK_WIDGET (gtk_builder_get_object (builder, "label_host"));
+	priv->label_user = GTK_WIDGET (gtk_builder_get_object (builder, "label_user"));
+	priv->label_port = GTK_WIDGET (gtk_builder_get_object (builder, "label_port"));
+	priv->button_connect = GTK_WIDGET (gtk_builder_get_object (builder, "button_connect"));
+
+	priv->label_mailbox_owner = GTK_WIDGET (gtk_builder_get_object (builder, "label_mailbox_owner"));
+	priv->label_quota_limit = GTK_WIDGET (gtk_builder_get_object (builder, "label_assigned"));
+	priv->label_quota_free = GTK_WIDGET (gtk_builder_get_object (builder, "label_free"));
+
+	priv->entry_quota_new = GTK_WIDGET (gtk_builder_get_object (builder, "entry_quota_new"));
+	priv->button_quota_apply = GTK_WIDGET (gtk_builder_get_object (builder, "button_quota_apply"));
+
+	priv->button_user_create = GTK_WIDGET (gtk_builder_get_object (builder, "button_create_user"));
+	priv->button_user_remove = GTK_WIDGET (gtk_builder_get_object (builder, "button_remove_user"));
+	priv->label_mailbox_name = GTK_WIDGET (gtk_builder_get_object (builder, "label_mailbox_name"));
+
+	priv->expander_modify_quota = GTK_WIDGET (gtk_builder_get_object (builder, "expander_modify_quota"));
+	priv->expander_modify_acl = GTK_WIDGET (gtk_builder_get_object (builder, "expander_modify_acl"));
 	
-	priv->label_host     = glade_xml_get_widget (xml_page, "label_host");
-	priv->label_user     = glade_xml_get_widget (xml_page, "label_user");
-	priv->label_port     = glade_xml_get_widget (xml_page, "label_port");
-/*	priv->entry_pass     = glade_xml_get_widget (xml_page, "entry_pass"); */
-	priv->button_connect = glade_xml_get_widget (xml_page, "button_connect");
+	table = GTK_WIDGET (gtk_builder_get_object (builder , "table_page"));
+	gtk_box_pack_start (GTK_BOX (admin), table, TRUE, TRUE, 0);
 
-	priv->label_mailbox_owner =
-		glade_xml_get_widget (xml_page, "label_mailbox_owner");
-	priv->label_quota_limit   =
-		glade_xml_get_widget (xml_page, "label_assigned");
-	priv->label_quota_free    =
-		glade_xml_get_widget (xml_page, "label_free");
-
-	priv->entry_quota_new    =
-		glade_xml_get_widget (xml_page, "entry_quota_new");
-	priv->button_quota_apply =
-		glade_xml_get_widget (xml_page, "button_quota_apply");
-
-	priv->button_user_create =
-		glade_xml_get_widget (xml_page, "button_create_user");
-	priv->button_user_remove =
-		glade_xml_get_widget (xml_page, "button_remove_user");
-	priv->label_mailbox_name  =
-		glade_xml_get_widget (xml_page, "label_mailbox_name");
-
-	priv->expander_modify_quota =
-		glade_xml_get_widget (xml_page, "expander_modify_quota");
-	priv->expander_modify_acl   =
-		glade_xml_get_widget (xml_page, "expander_modify_acl");
-	
-	table = glade_xml_get_widget (xml_page , "table_page");
-	gtk_box_pack_start_defaults (GTK_BOX (admin), table);
+	g_object_unref (builder);
 
 	admin->priv = priv;
 }
@@ -250,7 +234,8 @@ gyrus_admin_init (GyrusAdmin *admin)
 {
 	admin->priv = GYRUS_ADMIN_GET_PRIVATE (admin);
 	admin->priv->session = NULL;
-	
+	admin->priv->buffer = NULL;
+
 	gyrus_admin_init_get_widgets (admin);
 	gyrus_admin_initialize_mailbox_tree_view (admin, FALSE);
 	gyrus_admin_initialize_acl_tree_view (admin);
@@ -271,19 +256,14 @@ gyrus_admin_finalize (GObject *object)
 	
 	gyrus_session_free (admin->priv->session);
 
+	if (admin->priv->buffer) {
+		g_free (admin->priv->buffer);
+		admin->priv->buffer = NULL;
+	}
+
 	G_OBJECT_CLASS (gyrus_admin_parent_class)->finalize (object);
 }
 
-static void
-gyrus_admin_destroy (GtkObject *object)
-{
-	GyrusAdmin *admin;
-	g_return_if_fail (GYRUS_IS_ADMIN (object));
-	admin = GYRUS_ADMIN (object);
-
-	GTK_OBJECT_CLASS (gyrus_admin_parent_class)->destroy (object);
-}
-
 GtkTreeModel *
 gyrus_admin_mailbox_tree_model_new (void)
 {
@@ -308,8 +288,8 @@ gyrus_admin_get_mailbox_from_list_message (gchar *msg)
 				iterator++;
 			iterator ++;
 	}
-	/* to remove the "\n\0" */
-	large = strlen (iterator) - 2;
+	/* to remove the "\0" */
+	large = strlen (iterator) - 1;
 	
 	if (*iterator == '\"') {
 		iterator ++;
@@ -325,9 +305,8 @@ gyrus_admin_set_separator_char_auto (GyrusAdmin *admin)
 {
 	gchar **str_v;
 	gchar *msg = g_strdup (". list \"\" \"\"\n");
-	GIOError error = G_IO_ERROR_NONE;
 
-	error = gyrus_admin_write_channel (admin, msg);
+	gyrus_admin_write_channel (admin, msg);
 	g_free (msg);
 
 	gyrus_admin_listen_channel (admin, &msg, NULL);
@@ -350,7 +329,7 @@ gyrus_admin_get_users_list (GyrusAdmin *admin)
 	GtkTreeStore *store_corrupt;
 	gchar *msg;
 	gchar **current_mailbox;
-	GIOError error = G_IO_ERROR_NONE;
+	gboolean success;
 	gint depth, old_depth = 1;
 	GtkTreeIter iter_new, iter_parent, iter_child, iter_corrupt;
 	gboolean is_valid;
@@ -369,9 +348,9 @@ gyrus_admin_get_users_list (GyrusAdmin *admin)
 	gtk_tree_store_clear (store_corrupt);
 
 	msg = g_strdup (". list * *\n");
-	error = gyrus_admin_write_channel (admin, msg);
+	success = gyrus_admin_write_channel (admin, msg);
 	g_free (msg);
-	g_return_if_fail (error == G_IO_ERROR_NONE);
+	g_return_if_fail (success == TRUE);
 
 	while ((status = gyrus_admin_listen_channel (admin, &msg, NULL)) ==
 	       GYRUS_IMAP_STATUS_LIST) {
@@ -658,47 +637,91 @@ gyrus_admin_initialize_acl_tree_view (GyrusAdmin *admin)
 	gtk_tree_view_set_model (view, GTK_TREE_MODEL (model));
 }
 
-static GTcpSocket *
-gyrus_admin_create_socket_from_session (GyrusSession *session)
+static GSocketClient *
+gyrus_admin_create_socket_from_session (GyrusAdmin *admin, GyrusSession *session)
 {
-	GInetAddr *addr;
-	GTcpSocket *sock;
+	GSocketClient *sock;
+	GSocketConnectable *connectable;
 	gchar *msg;
 
 	g_return_val_if_fail (session, NULL);
-	
-	addr = gnet_inetaddr_new (session->host, session->port);
-	if (!addr) {
-		msg = g_strdup_printf (_("%s could not be found. Please check the name and try again."),
-				       session->host);
+
+	sock = g_socket_client_new ();
+	if (sock == NULL) {
+		msg = g_strdup (_("Couldn't create the client socket."));
 		gyrus_common_show_message (NULL, GTK_MESSAGE_ERROR, msg);
 		g_free (msg);
 		return NULL;
 	}
 
-	sock = gnet_tcp_socket_new (addr);
-	gnet_inetaddr_delete (addr);
+	connectable = g_network_address_parse (session->host, session->port, NULL);
+	if (connectable == NULL) {
+		msg = g_strdup (_("Couldn't parse the server address."));
+		gyrus_common_show_message (NULL, GTK_MESSAGE_ERROR, msg);
+		g_free (msg);
+		g_object_unref (sock);
+		return NULL;
+	}
 
-	if (!sock) {
+	admin->priv->connection = g_socket_client_connect (sock, connectable, NULL, NULL);
+	if (admin->priv->connection == NULL) {
 		msg = g_strdup_printf (_("Could not connect to %s, port %d."),
 				       session->host, session->port);
 		gyrus_common_show_message (NULL, GTK_MESSAGE_ERROR, msg);
 		g_free (msg);
+		g_object_unref (sock);
 		return NULL;
 	}
+	g_object_unref (connectable);
 
 	return sock;
 }
 
-static void
-gyrus_admin_initialize_channel (GyrusAdmin *admin)
+static gchar *
+socket_readline (GyrusAdmin *admin, gsize *len)
 {
-	g_return_if_fail (admin->priv->iochannel == NULL);
-	g_return_if_fail (admin->priv->tcp_socket);
-	admin->priv->iochannel =
-		gnet_tcp_socket_get_io_channel (admin->priv->tcp_socket);
-	
-	g_assert (admin->priv->iochannel);
+	GInputStream *stream;
+	gchar *retval;
+	gchar **toks;
+	gchar *n_buffer;
+	stream = g_io_stream_get_input_stream (G_IO_STREAM (admin->priv->connection));
+
+	if (admin->priv->buffer == NULL) {
+		admin->priv->buffer = g_malloc0 (BUFFER_SIZE * sizeof (gchar));
+		g_input_stream_read (stream, admin->priv->buffer,
+				     BUFFER_SIZE - 1, NULL, NULL);
+	}
+
+	toks = g_strsplit (admin->priv->buffer, "\n", 2);
+	g_free (admin->priv->buffer);
+
+	/* "Someth". We need to feed the buffer. */
+	while (toks[0] != NULL && toks[1] == NULL) {
+		admin->priv->buffer = g_malloc0 (BUFFER_SIZE * sizeof (gchar));
+		g_input_stream_read (stream,
+				     admin->priv->buffer,
+				     BUFFER_SIZE - 1,
+				     NULL, NULL);
+
+		n_buffer = g_strconcat (toks[0], admin->priv->buffer, NULL);
+		g_free (admin->priv->buffer);
+		g_strfreev (toks);
+		toks = g_strsplit (n_buffer, "\n", 2);
+		g_free (n_buffer);
+	}
+
+	retval = toks[0];
+	admin->priv->buffer = toks[1];
+	g_free (toks);
+
+	if (admin->priv->buffer && strcmp (admin->priv->buffer, "") == 0) {
+		g_free (admin->priv->buffer);
+		admin->priv->buffer = NULL;
+	}
+
+	*len = strlen (retval);
+
+	return retval;
 }
 
 /* Allocates @msg_len bytes of memory to store the message.
@@ -706,10 +729,9 @@ gyrus_admin_initialize_channel (GyrusAdmin *admin)
 GyrusImapStatus
 gyrus_admin_listen_channel (GyrusAdmin *admin, gchar **message, gint *msg_len)
 {
-	gchar buffer[BUFFER_SIZE];
 	gsize bytes_read;
 	gchar **tokens = NULL;
-	GIOError error;
+	GError *error = NULL;
 	GyrusImapStatus imap_status;
 
 	*message = NULL;
@@ -722,19 +744,11 @@ gyrus_admin_listen_channel (GyrusAdmin *admin, gchar **message, gint *msg_len)
 
 		error = G_IO_ERROR_NONE;
 		imap_status = GYRUS_IMAP_STATUS_OK;
-		
-		error = gnet_io_channel_readline (admin->priv->iochannel,
-						  buffer, BUFFER_SIZE,
-						  &bytes_read);
-		if (error != G_IO_ERROR_NONE) {
-			g_warning ("%i", error);
-			return TRUE;
-		}
-		
+		*message = socket_readline (admin, &bytes_read);
+
 #ifdef DEBUG_PLAIN_CHANNEL
-		g_print ("read:  %s", buffer);
+		g_print ("read:  %s", *message);
 #endif
-		*message = g_strdup (buffer);
 		tokens = g_strsplit (*message, " ", 0);
 		if (msg_len != NULL)
 			*msg_len = bytes_read;
@@ -764,20 +778,26 @@ gyrus_admin_listen_channel (GyrusAdmin *admin, gchar **message, gint *msg_len)
 	return imap_status;
 }
 
-GIOError
+gboolean
 gyrus_admin_write_channel (GyrusAdmin *admin, gchar *message)
 {
+	GOutputStream *stream;
 	guint msg_len;
 	gsize bytes_written;
-	GIOError error = G_IO_ERROR_NONE;
+	GError *error = NULL;
 
 	msg_len = g_utf8_strlen (message, -1);
-	error = gnet_io_channel_writen (admin->priv->iochannel, message,
-					msg_len, &bytes_written);
+	stream = g_io_stream_get_output_stream (G_IO_STREAM (admin->priv->connection));
+	bytes_written = g_output_stream_write (stream, message, msg_len, NULL, &error);
 #ifdef DEBUG_PLAIN_CHANNEL
- 	g_print ("written: %s", message); 
+	g_print ("written: %s", message);
 #endif
-	return error;
+	if (error) {
+		g_error_free (error);
+		return FALSE;
+	} else {
+		return TRUE;
+	}
 }
 
 gboolean
@@ -792,8 +812,15 @@ gyrus_admin_logout (GyrusAdmin *admin)
 	status = gyrus_admin_listen_channel (admin, &msg, NULL);
 
 	if (status == GYRUS_IMAP_STATUS_BYE) {
-		gnet_tcp_socket_delete(admin->priv->tcp_socket);
-		admin->priv->iochannel = NULL;
+		g_io_stream_close (G_IO_STREAM (admin->priv->connection), NULL, NULL);
+		g_object_unref (admin->priv->connection);
+		admin->priv->connection = NULL;
+
+		g_object_unref (admin->priv->tcp_socket);
+		admin->priv->tcp_socket = NULL;
+
+		g_free (admin->priv->buffer);
+		admin->priv->buffer = NULL;
 		g_free (msg);
 	}
 
@@ -819,14 +846,8 @@ gyrus_admin_clean_mailbox_treeview (GtkTreeView *treeview, const gchar *title)
 void
 gyrus_admin_logged_out (GyrusAdmin *admin)
 {
-	GtkWidget *btn_image;
-	
 	gtk_button_set_label (GTK_BUTTON (admin->priv->button_connect),
-			      _("_Connect"));
-
-	btn_image = gtk_image_new_from_stock (GTK_STOCK_CONNECT, GTK_ICON_SIZE_BUTTON);
-	gtk_button_set_image (GTK_BUTTON (admin->priv->button_connect),
-			      btn_image);
+			      GTK_STOCK_CONNECT);
 
 	gyrus_admin_clean_mailbox_treeview (GTK_TREE_VIEW (admin->priv->treeview_users), 
 					    _("Users"));
@@ -887,19 +908,17 @@ imap_quote_string (const char *str)
 static GyrusAdminLoginError
 gyrus_admin_login (GyrusAdmin *admin)
 {
-	GTcpSocket *socket;
+	GSocketClient *socket;
 	gchar *msg;
 	gchar *q_password;
 	GyrusImapStatus status;
 	GyrusAdminLoginError error = GYRUS_ADMIN_LOGIN_OK;
-	socket = gyrus_admin_create_socket_from_session (admin->priv->session);
+	socket = gyrus_admin_create_socket_from_session (admin, admin->priv->session);
 	if (!socket)
 		return GYRUS_ADMIN_LOGIN_NO_HOST;
 	
 	admin->priv->tcp_socket = socket;
 
-	gyrus_admin_initialize_channel (admin);
-
 	status = gyrus_admin_listen_channel (admin, &msg, NULL);
 	g_free (msg);
 
@@ -992,13 +1011,8 @@ gyrus_admin_pre_login (GyrusAdmin *admin)
 				/* do something useful here */
 			}
 			else {
-				GtkWidget *btn_image;
 				gtk_button_set_label (GTK_BUTTON (admin->priv->button_connect),
-						      _("_Disconnect"));
-				btn_image = gtk_image_new_from_stock (GTK_STOCK_DISCONNECT, 
-								      GTK_ICON_SIZE_BUTTON);
-				gtk_button_set_image (GTK_BUTTON (admin->priv->button_connect),
-						      btn_image);
+						      GTK_STOCK_DISCONNECT);
 				gyrus_admin_post_login (admin);
 				/* correctly logged in */
 				keep_asking = FALSE;
@@ -1082,7 +1096,7 @@ gyrus_admin_is_connected (GyrusAdmin *admin)
 {
 	g_return_val_if_fail (GYRUS_IS_ADMIN (admin), FALSE);
 	g_return_val_if_fail (admin != NULL, FALSE);
-	return (admin->priv->iochannel != NULL);
+	return (admin->priv->connection != NULL);
 }
 
 const gchar*
