@@ -25,7 +25,6 @@
 
 #include <gtk/gtk.h>
 #include <string.h>
-#include <glade/glade.h>
 #include "glib/gi18n.h"
 #include "gyrus-common.h"
 
@@ -65,19 +64,22 @@ gyrus_gtk_entry_has_text (GtkEntry *entry)
 gchar *
 gyrus_dialog_password_new (void)
 {
-	GladeXML *xml;
-	gchar *file_glade;
+	gchar *file_xml;
 	GtkWidget *dialog;
 	GtkWidget *entry_password;
 	gchar *password = NULL;
 	gint result;
+	GtkBuilder *builder;
 
-	file_glade = g_build_filename (GYRUS_GLADE_DIR, "page.glade", NULL);
-	xml = glade_xml_new (file_glade, "dialog_password", "gyrus");
-	g_free (file_glade);
+	file_xml = g_build_filename (GYRUS_UI_DIR, "password.xml", NULL);
+
+        builder = gtk_builder_new ();
+        gtk_builder_add_from_file (builder, file_xml, NULL);
+
+	g_free (file_xml);
 	
-	dialog         = glade_xml_get_widget (xml, "dialog_password");
-	entry_password = glade_xml_get_widget (xml, "entry_password");
+	dialog = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_password"));
+	entry_password = GTK_WIDGET (gtk_builder_get_object (builder, "entry_password"));
 	
 	result = gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -91,6 +93,8 @@ gyrus_dialog_password_new (void)
 	}
 	gtk_widget_destroy (dialog);
 
+	g_object_unref (builder);
+
 	return password;
 }
 
