@@ -26,15 +26,13 @@
 #include <config.h>
 
 #include <gtk/gtk.h>
-#include <glade/glade.h>
-#include <libgnomeui/libgnomeui.h>
+#include <stdlib.h>
 
 #include "glib/gi18n.h"
 #include "gyrus-dialog-mailbox-new.h"
 #include "gyrus-dialog-find-mailbox.h"
 #include "gyrus-main-app.h"
 #include "gyrus-session.h"
-#include "gyrus-preferences.h"
 #include "gyrus-admin-mailbox.h"
 #include "gyrus-report.h"
 
@@ -46,15 +44,30 @@ G_DEFINE_TYPE (GyrusMainApp, gyrus_main_app, GTK_TYPE_WINDOW)
 /*** Gyrus Main Application Private Data ***/
 struct _GyrusMainAppPrivate {
         GtkWidget *notebook;
+        GtkWidget *statusbar;
+        GtkWidget *progress_bar;
         GtkUIManager *ui_manager;
         GtkActionGroup *actions_window;
         GtkActionGroup *actions_server;
         GtkActionGroup *actions_mailbox;
         GtkActionGroup *actions_acl_item;
+        guint tip_message_cid;
 };
 
 static void gyrus_main_app_about (void);
 
+static void
+connect_proxy_cb (GtkUIManager *manager,
+                  GtkAction *action,
+                  GtkWidget *proxy,
+                  GyrusMainApp *app);
+
+static void
+disconnect_proxy_cb (GtkUIManager *manager,
+                     GtkAction *action,
+                     GtkWidget *proxy,
+                     GyrusMainApp *app);
+
 /*** Class Callbacks ***/
 
 static void
@@ -100,7 +113,7 @@ gyrus_main_app_on_edit_mailbox_add (GtkWidget *widget G_GNUC_UNUSED,
 	
 }
 
-void
+static void
 gyrus_admin_delete_dialog_on_response (GtkDialog *dialog,
 				       gint result,
 				       gpointer user_data)
@@ -142,13 +155,6 @@ gyrus_main_app_on_edit_mailbox_remove (GtkWidget *widget G_GNUC_UNUSED,
 	g_free (mailbox);
 }
 
-static void
-gyrus_main_app_on_edit_preferences (GtkWidget *widget G_GNUC_UNUSED,
-				    gpointer user_data)
-{
-	gyrus_preferences_show_dialog ();
-}
-
 static void
 gyrus_main_app_on_acl_entry_delete (GtkWidget *widget G_GNUC_UNUSED,
 				    gpointer user_data)
@@ -205,7 +211,7 @@ gyrus_main_app_on_help_about (GtkWidget *widget G_GNUC_UNUSED,
 	gyrus_main_app_about();
 }
 
-void
+static void
 gyrus_main_app_make_sensitivity_consistent (GyrusMainApp *app)
 {
 	gint n_page;
@@ -255,9 +261,9 @@ gyrus_main_app_on_button_close_page_clicked (GtkButton *button, gpointer data)
 		gtk_window_set_title (GTK_WINDOW (app), _("Cyrus IMAP Administrator"));
 }
 
-void
+static void
 gyrus_main_app_on_switch_page (GtkNotebook *notebook,
-			       GtkNotebookPage *page,
+			       gpointer *page,
 			       guint page_num,
 			       gpointer user_data)
 {
@@ -268,10 +274,12 @@ gyrus_main_app_on_switch_page (GtkNotebook *notebook,
 	const gchar *session_name = gyrus_admin_get_current_session_name (admin);
 	gchar *title = g_strdup_printf (_("%s - Cyrus IMAP Administrator"), 
 					session_name);
+	gchar *mailbox;
+	
 	gtk_window_set_title (GTK_WINDOW (app), title);
 	g_free (title);
 
-	gchar *mailbox;
+
 	if (gyrus_admin_is_connected (admin))
 		gtk_action_group_set_sensitive (app->priv->actions_server, TRUE);
 	else
@@ -342,8 +350,6 @@ static const char *ui_description =
 "    </menu>\n"
 "    <menu action='EditMenu'>\n"
 "      <menuitem action='Find'/>\n"
-/*"      <separator/>\n"
-  "      <menuitem action='Preferences'/>\n"*/
 "    </menu>\n"
 "    <menu action='AclMenu'>\n"
 "      <menuitem action='EntryNew'/>\n"
@@ -385,8 +391,6 @@ static const GtkActionEntry entries_window[] = {
 	  G_CALLBACK (gyrus_main_app_on_file_exit) },
 	{ "About", GTK_STOCK_ABOUT, NULL, NULL, NULL, 
 	  G_CALLBACK (gyrus_main_app_on_help_about) }
-/*  { "Preferences", GTK_STOCK_PREFERENCES, N_("_Preferences"), NULL, 
-    N_("Show the program preferences"), gyrus_main_app_on_edit_preferences } */
 };
 
 static const GtkActionEntry entries_server[] = {
@@ -420,7 +424,6 @@ gyrus_main_app_init (GyrusMainApp *app)
 {
 
 	GtkWidget *main_vbox;
-	GtkWidget *appbar;
 	GtkWidget *menubar;
 	GtkWidget *toolbar;
 	GtkAccelGroup *accel_group;
@@ -477,7 +480,12 @@ gyrus_main_app_init (GyrusMainApp *app)
 		g_error_free (error);
 		exit (EXIT_FAILURE);
 	}
-	
+
+	g_signal_connect (app->priv->ui_manager, "connect_proxy",
+			  G_CALLBACK (connect_proxy_cb), app);
+	g_signal_connect (app->priv->ui_manager, "disconnect_proxy",
+			  G_CALLBACK (disconnect_proxy_cb), app);
+
 	menubar = gtk_ui_manager_get_widget (app->priv->ui_manager, "/MainMenu");
 	gtk_box_pack_start (GTK_BOX (main_vbox), menubar, FALSE, FALSE, 0);
 
@@ -491,13 +499,24 @@ gyrus_main_app_init (GyrusMainApp *app)
 	
 	gtk_box_pack_start (GTK_BOX (main_vbox), app->priv->notebook,
 			    TRUE, TRUE, 0);
-	appbar = gnome_appbar_new (TRUE, TRUE, GNOME_PREFERENCES_USER);
 
-	gtk_box_pack_start (GTK_BOX (main_vbox), appbar,
+	app->priv->statusbar = gtk_statusbar_new ();
+
+	app->priv->progress_bar = gtk_progress_bar_new ();
+
+	app->priv->tip_message_cid = 
+		gtk_statusbar_get_context_id (GTK_STATUSBAR (app->priv->statusbar), 
+					      "tip_message");
+
+	gtk_box_pack_end (GTK_BOX (app->priv->statusbar), app->priv->progress_bar,
+			    FALSE, FALSE, 0);
+
+	gtk_box_pack_start (GTK_BOX (main_vbox), app->priv->statusbar,
 			    FALSE, FALSE, 0);
 
 	gtk_container_add (GTK_CONTAINER (app), 
 			   main_vbox);
+
 	gtk_widget_show_all (main_vbox);
 }
 
@@ -525,7 +544,8 @@ gyrus_main_app_about (void)
 		"nez <avaldes@utalca.cl>",
 		"Jorge Bustos Bustos <jbustos@utalca.cl>",
 		"Claudio Saavedra "
-		"<csaavedra@alumnos.utalca.cl>",
+		"<csaavedra@igalia.com>",
+		"Francisco Rojas <frojas@alumnos.utalca.cl>",
 		NULL
 	};
 
@@ -553,7 +573,7 @@ gyrus_main_app_about (void)
 	g_object_unref(pixbuf);
 }
 
-GtkWidget *
+static GtkWidget *
 gyrus_main_app_create_label_from_admin (GyrusMainApp *app, GyrusAdmin *admin)
 {
 	GtkWidget *hbox;
@@ -641,10 +661,13 @@ main_app_on_mailbox_selection_changed (GyrusAdmin *admin,
 GtkWidget *
 gyrus_main_app_append_page (GyrusMainApp *app, GyrusSession *session)
 {
-	g_return_val_if_fail (GYRUS_IS_MAIN_APP (app), NULL);
 	GtkWidget *hbox_label;
 	gint page_num;
-	GtkWidget *admin = gyrus_admin_new (session);
+	GtkWidget *admin;
+
+	g_return_val_if_fail (GYRUS_IS_MAIN_APP (app), NULL);
+
+	admin = gyrus_admin_new (session);
 
 	g_signal_connect (G_OBJECT (admin), "connected", 
 			  G_CALLBACK (main_app_on_admin_connected), 
@@ -688,9 +711,9 @@ gyrus_main_app_menu_set_sensitive (GyrusMainApp *app, gboolean sens)
 
 /***** Above functions doesnt belong this file ******/
 
-void
+static void
 gyrus_application_window_destroyed_callback (GtkWindow *window,
-					      gpointer userdata)
+					     gpointer userdata)
 {
 	gtk_main_quit();
 }
@@ -704,9 +727,9 @@ main (int argc, char *argv[])
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gnome_program_init ("gyrus", VERSION, LIBGNOMEUI_MODULE,
- 			    argc, argv,
-			    GNOME_PARAM_APP_DATADIR, GYRUS_DATA_DIR, NULL);
+	gtk_init (&argc, &argv);
+	g_set_prgname ("gyrus");
+	g_set_application_name (_("Cyrus IMAP Administrator"));
 
 	app = gyrus_main_app_new ();
 	gtk_window_set_default_size (GTK_WINDOW (app), 600, 400);
@@ -720,3 +743,57 @@ main (int argc, char *argv[])
 
 	return 0;
 }
+
+static void
+menu_item_select_cb (GtkMenuItem *proxy, GyrusMainApp *app)
+{
+	GtkAction *action;
+	char *message;
+
+	action = g_object_get_data (G_OBJECT (proxy), "gtk-action");
+
+	g_return_if_fail (action != NULL);
+
+	g_object_get (G_OBJECT (action), "tooltip", &message, NULL);
+
+	if (message) {
+		gtk_statusbar_push (GTK_STATUSBAR (app->priv->statusbar),
+				    app->priv->tip_message_cid, message);
+		g_free (message);
+	}
+}
+
+static void
+menu_item_deselect_cb (GtkMenuItem *proxy, GyrusMainApp *app)
+{
+	gtk_statusbar_pop (GTK_STATUSBAR (app->priv->statusbar),
+			   app->priv->tip_message_cid);
+}
+
+static void
+connect_proxy_cb (GtkUIManager *manager,
+                  GtkAction *action,
+                  GtkWidget *proxy,
+                  GyrusMainApp *app)
+{
+	if (GTK_IS_MENU_ITEM (proxy)) {
+		g_signal_connect (proxy, "select",
+				  G_CALLBACK (menu_item_select_cb), app);
+		g_signal_connect (proxy, "deselect",
+				  G_CALLBACK (menu_item_deselect_cb), app);
+	}
+}
+
+static void
+disconnect_proxy_cb (GtkUIManager *manager,
+                     GtkAction *action,
+                     GtkWidget *proxy,
+                     GyrusMainApp *app)
+{
+	if (GTK_IS_MENU_ITEM (proxy)) {
+		g_signal_handlers_disconnect_by_func
+			(proxy, G_CALLBACK (menu_item_select_cb), app);
+		g_signal_handlers_disconnect_by_func
+			(proxy, G_CALLBACK (menu_item_deselect_cb), app);
+	}
+}
