@@ -23,7 +23,6 @@
 
 #include <config.h>
 
-#include <glade/glade.h>
 #include "gyrus-report.h"
 #include "glib/gi18n.h"
 #include <glib/gprintf.h>
@@ -76,29 +75,31 @@ static void gyrus_report_on_button_print_clicked(GtkWidget *widget, GyrusReportD
 void
 gyrus_report_show_report (GyrusAdmin *admin)
 {
-	GladeXML *xml;
-       	gchar *file_glade;
-	
+	gchar *file_xml;
+	GtkBuilder *builder;
+
 	GtkWidget *button_cancel;
 	GtkWidget *button_preview;
 	GtkWidget *button_update;
-	
+
 	GyrusReportData *report;
 	report = g_new0 (GyrusReportData,1);
 
 	report->mailbox_temp = NULL;
 	report->admin = admin;
-	
-	file_glade = g_build_filename (GYRUS_GLADE_DIR, "report.glade", NULL);
-	xml = glade_xml_new (file_glade, NULL, NULL);
 
-	report->window_report = glade_xml_get_widget (xml, "window-report");
-	button_cancel = glade_xml_get_widget (xml, "button-cancel");
-	button_preview = glade_xml_get_widget (xml, "button-preview");
-	button_update = glade_xml_get_widget (xml, "button-update");
-	report->spin_report = glade_xml_get_widget (xml, "spinbutton-percentage");
-	report->treeview_report = GTK_TREE_VIEW (glade_xml_get_widget (xml,"treeview-report"));
-	report->button_print = glade_xml_get_widget (xml, "button-print");
+	file_xml = g_build_filename (GYRUS_UI_DIR, "report.xml", NULL);
+
+	builder = gtk_builder_new ();
+	gtk_builder_add_from_file (builder, file_xml, NULL);
+
+	report->window_report = GTK_WIDGET (gtk_builder_get_object (builder, "window-report"));
+	button_cancel = GTK_WIDGET (gtk_builder_get_object (builder, "button-cancel"));
+	button_preview = GTK_WIDGET (gtk_builder_get_object (builder, "button-preview"));
+	button_update = GTK_WIDGET (gtk_builder_get_object (builder, "button-update"));
+	report->spin_report = GTK_WIDGET (gtk_builder_get_object (builder, "spinbutton-percentage"));
+	report->treeview_report = GTK_TREE_VIEW (gtk_builder_get_object (builder,"treeview-report"));
+	report->button_print = GTK_WIDGET (gtk_builder_get_object (builder, "button-print"));
 
 	gtk_widget_set_sensitive (report->button_print, FALSE);
 
@@ -122,14 +123,14 @@ gyrus_report_show_report (GyrusAdmin *admin)
 	g_signal_connect (G_OBJECT (button_update), "clicked",
                           G_CALLBACK (gyrus_report_on_button_update_clicked),
                           report);
-	
+
 	g_signal_connect (G_OBJECT (report->button_print), "clicked",
                           G_CALLBACK (gyrus_report_on_button_print_clicked),
                           report);
 	gtk_widget_show_all (report->window_report);
-	g_object_unref (xml);
-	
-	g_free (file_glade);
+
+	g_free (file_xml);
+	g_object_unref (builder);
 }
 
 
@@ -148,7 +149,7 @@ gyrus_report_cell_data_func (GtkTreeViewColumn *tree_column,
 			   -1);
 	
 	g_snprintf(buf, sizeof(buf), 
-		   "%.1f", perc);
+				"%.1f", perc);
 	
 	g_object_set(renderer, "text", 
 		     buf, NULL);
@@ -318,7 +319,8 @@ gyrus_report_evaluate_quota (GtkTreeModel *model,
 	GtkListStore *store;
 	GtkTreeIter iter_new;	
 
-	gint per = report->n_percen;	gboolean passed = TRUE;
+	gint per = report->n_percen;
+	gboolean passed = TRUE;
 
 	store = GTK_LIST_STORE (gtk_tree_view_get_model (report->treeview_report));
 
