@@ -27,7 +27,6 @@
 
 #include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <gdk/gdkkeysyms.h>
 #include <string.h>
 
@@ -81,6 +80,7 @@ static GtkWidget *spinbutton_port;
 static GtkWidget *entry_name;
 static GtkWidget *treeview_sessions;
 static GtkTreeModel *model_sessions;
+static GtkListStore *model_separator;
 
 static GtkWidget *button_session_edit_ok;
 static GtkWidget *button_session_edit_cancel;
@@ -412,11 +412,10 @@ gyrus_session_set_defaults_from_session (GyrusSession *session)
 	g_return_if_fail (session);
 
 	gtk_entry_set_text (GTK_ENTRY (entry_host), session->host);
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton_port),
-				   (gdouble) session->port);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton_port), (gdouble) session->port);
 	gtk_entry_set_text (GTK_ENTRY (entry_user), session->user);
 	gtk_entry_set_text (GTK_ENTRY (entry_name), session->name);
-	
+
 	if (strcmp (session->sep_char, ".") == 0)
 		value = 0;
 	else if (strcmp (session->sep_char, "/") == 0)
@@ -582,6 +581,23 @@ gyrus_session_create_model_sessions (void)
 	model_sessions = GTK_TREE_MODEL (model);
 }
 
+static void
+gyrus_session_create_model_separator (void)
+{
+	GtkTreeIter iter;
+
+	model_separator = gtk_list_store_new (1,G_TYPE_STRING);
+
+	gtk_list_store_append(GTK_LIST_STORE(model_separator), &iter);
+	gtk_list_store_set (GTK_LIST_STORE(model_separator), &iter,0,".", -1);
+
+	gtk_list_store_append(GTK_LIST_STORE(model_separator), &iter);
+	gtk_list_store_set (GTK_LIST_STORE(model_separator), &iter,0,"/", -1);
+
+	gtk_list_store_append(GTK_LIST_STORE(model_separator), &iter);
+	gtk_list_store_set (GTK_LIST_STORE(model_separator), &iter,0, _("Autodetect"), -1);
+}
+
 /* If remove is TRUE, the selected item is removed from the array */
 static GyrusSession *
 gyrus_session_get_selected_session (gboolean remove)
@@ -709,21 +725,24 @@ gyrus_session_open (GyrusSession *session, gpointer user_data)
 static void
 gyrus_session_load_interface (gpointer user_data)
 {
-	GladeXML *xml;
-	gchar *file_glade;
+	gchar *file_xml;
+	GtkBuilder *builder;
         
-	file_glade = g_build_filename (GYRUS_GLADE_DIR, "sessions.glade", NULL);
-	xml = glade_xml_new (file_glade, "dialog_sessions", "gyrus");
-	g_free (file_glade);
+	file_xml = g_build_filename (GYRUS_UI_DIR, "sessions.xml", NULL);
+
+	builder = gtk_builder_new ();
+        gtk_builder_add_from_file (builder, file_xml, NULL);
+
+	g_free (file_xml);
 	
-	window            = glade_xml_get_widget (xml, "dialog_sessions");
+	window = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_sessions"));
 	
-	treeview_sessions = glade_xml_get_widget (xml, "treeview_sessions");
-	button_new        = glade_xml_get_widget (xml, "button_new");
-	button_open       = glade_xml_get_widget (xml, "button_open");
-	button_delete     = glade_xml_get_widget (xml, "button_delete");
-	button_cancel     = glade_xml_get_widget (xml, "button_cancel");
-	button_properties = glade_xml_get_widget (xml, "button_properties");
+	treeview_sessions = GTK_WIDGET (gtk_builder_get_object (builder, "treeview_sessions"));
+	button_new = GTK_WIDGET (gtk_builder_get_object (builder, "button_new"));
+	button_open = GTK_WIDGET (gtk_builder_get_object (builder, "button_open"));
+	button_delete = GTK_WIDGET (gtk_builder_get_object (builder, "button_delete"));
+	button_cancel = GTK_WIDGET (gtk_builder_get_object (builder, "button_cancel"));
+	button_properties = GTK_WIDGET (gtk_builder_get_object (builder, "button_properties"));
 	
 	/* connect signals */
 	g_signal_connect (G_OBJECT (window), "delete_event",
@@ -761,29 +780,43 @@ gyrus_session_load_interface (gpointer user_data)
 	gyrus_session_set_treeview ();
 	gyrus_session_list_set_sensitive (FALSE);
 	gyrus_session_create_model_sessions ();
-	g_object_unref (xml);
+	gyrus_session_create_model_separator ();
 }
 
 static void
 gyrus_session_edit_load_interface (gpointer user_data)
 {
-	GladeXML *xml;
-	gchar *file_glade;
+	gchar *file_xml;
+	GtkBuilder *builder;
+	GtkCellRenderer *cell;
         
-	file_glade = g_build_filename (GYRUS_GLADE_DIR, "sessions.glade", NULL);
-	xml = glade_xml_new (file_glade, "dialog_session_edit", "gyrus");
-	g_free (file_glade);
-	
-	window_edit       = glade_xml_get_widget (xml, "dialog_session_edit");
-	checkbutton_secure= glade_xml_get_widget (xml, "checkbutton_secure");
-	entry_host        = glade_xml_get_widget (xml, "entry_host");
-	entry_user        = glade_xml_get_widget (xml, "entry_user");
-	entry_passwd      = glade_xml_get_widget (xml, "entry_passwd");
-	combobox_sep_char      = glade_xml_get_widget (xml, "combobox_sep_char");
-	spinbutton_port   = glade_xml_get_widget (xml, "spinbutton_port");
-	button_session_edit_ok  = glade_xml_get_widget (xml, "button_session_edit_ok");
-	button_session_edit_cancel = glade_xml_get_widget (xml, "button_session_edit_cancel");
-	entry_name        = glade_xml_get_widget (xml, "entry_name");
+	file_xml = g_build_filename (GYRUS_UI_DIR, "sessions_edit.xml", NULL);
+
+	builder = gtk_builder_new ();
+        gtk_builder_add_from_file (builder, file_xml, NULL);
+
+	g_free (file_xml);
+
+	window_edit = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_session_edit"));
+	checkbutton_secure = GTK_WIDGET (gtk_builder_get_object (builder, "checkbutton_secure"));
+	entry_host = GTK_WIDGET (gtk_builder_get_object (builder, "entry_host"));
+	entry_user = GTK_WIDGET (gtk_builder_get_object (builder, "entry_user"));
+	entry_passwd = GTK_WIDGET (gtk_builder_get_object (builder, "entry_passwd"));
+	combobox_sep_char = GTK_WIDGET (gtk_builder_get_object (builder, "combobox_sep_char"));
+	spinbutton_port = GTK_WIDGET (gtk_builder_get_object (builder, "spinbutton_port"));
+	button_session_edit_ok = GTK_WIDGET (gtk_builder_get_object (builder, "button_session_edit_ok"));
+	button_session_edit_cancel = GTK_WIDGET (gtk_builder_get_object (builder, "button_session_edit_cancel"));
+	entry_name = GTK_WIDGET (gtk_builder_get_object (builder, "entry_name"));
+
+	g_object_unref (builder);
+
+	/* set model to combobox of mailbox hierarchy separator */
+	gtk_combo_box_set_model (GTK_COMBO_BOX (combobox_sep_char), GTK_TREE_MODEL (model_separator));
+	cell = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT (combobox_sep_char), cell, TRUE);
+	gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT (combobox_sep_char), cell, "text", 0, NULL);
+
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinbutton_port), 143);
 
 	g_signal_connect (G_OBJECT (button_session_edit_cancel), "clicked",
 			  G_CALLBACK (gyrus_session_edit_on_button_cancel_clicked),
@@ -816,7 +849,6 @@ gyrus_session_edit_load_interface (gpointer user_data)
 	gtk_window_set_modal (GTK_WINDOW (window_edit), TRUE);
 	gtk_window_set_transient_for (GTK_WINDOW (window_edit), GTK_WINDOW (window));
 	gtk_widget_grab_default (button_session_edit_ok);
-	g_object_unref (xml);
 }
 
 /* show window sessions */
